// Copyright (C) 2000-2016 Synology Inc. All rights reserved.

Ext.ns("SYNO.SDS.JAVA7");

SYNO.SDS.JAVA7.CGI_JAVA = "/webman/3rdparty/Java7/java.cgi";

Ext.define('SYNO.SDS.JAVA7.Instance', {
	extend: 'SYNO.SDS.AppInstance',
	appWindowName: 'SYNO.SDS.JAVA7.Manager',
	constructor: function() {
		this.callParent(arguments);
	}
});

Ext.define('SYNO.SDS.JAVA7.MainPanel', {
	extend: 'SYNO.SDS.Utils.FormPanel',
	defaultValue: "--",
	constructor: function(cfg) {
		var config = Ext.apply({
			border: false,
			items: [{
					xtype: 'syno_displayfield',
					itemId: 'status',
					fieldLabel: _TT("SYNO.SDS.JAVA7.Instance", 'main', 'java_status'),
					value: this.defaultValue
				}, {
					xtype: 'syno_displayfield',
					itemId: 'javaversion',
					fieldLabel: _TT("SYNO.SDS.JAVA7.Instance", "main", "java_version"),
					value: this.defaultValue
				}, {
					xtype: 'syno_displayfield',
					itemId: 'classpath',
					fieldLabel: "CLASSPATH",
					value: this.defaultValue
				}, {
					xtype: 'syno_compositefield',
					itemId: 'buttons',
					hideLabel: true,
					items: [
					{
						name: 'install',
						xtype: 'syno_button',
						id: (this.installID = Ext.id()),
						text: _TT("SYNO.SDS.JAVA7.Instance", "main", "install_java"),
						isFormField: true,
						hidden: true
					}, {
						name: 'upgrade',
						xtype: 'syno_button',
						id: (this.upgradeID = Ext.id()),
						text: _TT("SYNO.SDS.JAVA7.Instance", "main", "upgrade_java"),
						isFormField: true,
						hidden: true
					}]
				}]
		}, cfg);
		this.owner = cfg.owner;
		this.callParent([config]);
	},
	initEvents: function() {
		this.callParent(arguments);
		this.mon(this, 'afterlayout', function() {
			this.mon(Ext.getCmp(this.installID), 'click', this.openInstaller, this);
			this.mon(Ext.getCmp(this.upgradeID), 'click', this.openInstaller, this);
			this.requestStatus();
		}, this, {single: true});
	},
	openInstaller: function(obj, e) {
		var installer = new SYNO.SDS.JAVA7.Installer({
			owner: this.owner
		}, obj.id === this.upgradeID);
		this.mon(installer, 'close', this.onWizardClose, this);
		installer.open();
	},
	onWizardClose: function() {
		this.requestStatus();
	},
	setButton: function(blInstall, blUpgrade, blRemove) {
		Ext.getCmp(this.installID).setVisible(blInstall);
		Ext.getCmp(this.upgradeID).setVisible(blUpgrade);
		this.doLayout();
	},
	fillStatus: function(statusText, javaversionText, classpathText) {
		var status = this.getComponent('status');
		var javaversion = this.getComponent('javaversion');
		var classpath = this.getComponent('classpath');
		
		if (undefined === statusText || undefined === javaversionText ||
			undefined === classpathText) {
			SYNO.Debug('wrong parameters for fillStatus');
		}

		status.setValue(statusText);
		javaversion.setValue(javaversionText);
		classpath.setValue(classpathText);
	},
	update: function(isInstall, javaVersion, classpath) {
		var statusText = "";
		var status = this.getComponent('status');

		if (!javaVersion) {
			javaVersion = this.defaultValue;
		}
		if (!classpath) {
			classpath = this.defaultValue;
		}
		if (!isInstall) {
			statusText = _TT("SYNO.SDS.JAVA7.Instance", "main", "not_installed");
			status.removeClass("java_manager_installed");
			status.addClass("java_manager_uninstalled");
			this.setButton(true, false, false);
		} else {
			statusText = _TT("SYNO.SDS.JAVA7.Instance", "main", "installed");
			status.addClass("java_manager_installed");
			status.removeClass("java_manager_uninstalled");
			this.setButton(false, true, true);
		}
		this.fillStatus(statusText, javaVersion, classpath);
	},
	requestStatus: function() {
		this.owner.setStatusBusy();
		var onSuccess = function(response, opts) {
			// check for undefined
			var data = Ext.decode(response.responseText).data;

			this.update(data.installed, data.java_version, data.classpath);
			this.owner.clearStatusBusy();
		};
		Ext.Ajax.request({
			url: SYNO.SDS.JAVA7.CGI_JAVA,
			params: { action: "load" },
			scope: this,
			success: onSuccess,
			failure: function(response, opts) {
				this.owner.getMsgBox().alert(this.owner.title, _T("error", "error_unknown"));
				this.owner.clearStatusBusy();
			}
		});
	}
});

Ext.define('SYNO.SDS.JAVA7.Manager', {
	extend: 'SYNO.SDS.AppWindow',
	appInstance: null,
	mainPanel: null,

	constructor: function(cfg) {
		this.appInstance = cfg.appInstance;
		this.mainPanel = new SYNO.SDS.JAVA7.MainPanel({owner: this});

		var config = Ext.apply({
				resizable: false,
				maximizable: false,
				minimizable: true,
				width: 600,
				height: 300,
				dsmStyle: 'v5',
				layout: 'fit',
				items: [
					this.mainPanel
				]
		}, cfg);

		this.callParent([config]);
	}
});
